Skip to content
This repository was archived by the owner on Nov 24, 2025. It is now read-only.

Commit 200751d

Browse files
committed
chore: bump llama.cpp
Signed-off-by: thxCode <thxcode0824@gmail.com>
1 parent 3be63eb commit 200751d

7 files changed

Lines changed: 17 additions & 17 deletions

File tree

llama-box/patches/llama.cpp/dynamic_link.patch

Lines changed: 1 addition & 1 deletion
Original file line numberDiff line numberDiff line change
@@ -1,5 +1,5 @@
11
diff --git a/ggml/src/ggml-cpu/ggml-cpu.cpp b/ggml/src/ggml-cpu/ggml-cpu.cpp
2-
index e16cdc9d4..b8d1c41e5 100644
2+
index 8dacd3671..daf09e224 100644
33
--- a/ggml/src/ggml-cpu/ggml-cpu.cpp
44
+++ b/ggml/src/ggml-cpu/ggml-cpu.cpp
55
@@ -632,6 +632,18 @@ static void * ggml_backend_cpu_get_proc_address(ggml_backend_reg_t reg, const ch

llama-box/patches/llama.cpp/ggml-hip.patch

Lines changed: 2 additions & 2 deletions
Original file line numberDiff line numberDiff line change
@@ -1,5 +1,5 @@
11
diff --git a/ggml/src/ggml-cuda/common.cuh b/ggml/src/ggml-cuda/common.cuh
2-
index 8f2725547..47624876e 100644
2+
index 2e5d48797..a79b27431 100644
33
--- a/ggml/src/ggml-cuda/common.cuh
44
+++ b/ggml/src/ggml-cuda/common.cuh
55
@@ -60,6 +60,10 @@
@@ -22,7 +22,7 @@ index 8f2725547..47624876e 100644
2222
#define GGML_CUDA_CC_IS_CDNA3(cc) (cc >= GGML_CUDA_CC_CDNA3 && cc < GGML_CUDA_CC_RDNA1)
2323

2424
// Moore Threads
25-
@@ -512,7 +516,7 @@ static __device__ __forceinline__ uint32_t __hgt2_mask(const half2 a, const half
25+
@@ -520,7 +524,7 @@ static __device__ __forceinline__ uint32_t __hgt2_mask(const half2 a, const half
2626

2727
static __device__ __forceinline__ int ggml_cuda_dp4a(const int a, const int b, int c) {
2828
#if defined(GGML_USE_HIP)

llama-box/patches/llama.cpp/ggml-rpc.patch

Lines changed: 1 addition & 1 deletion
Original file line numberDiff line numberDiff line change
@@ -1,5 +1,5 @@
11
diff --git a/ggml/src/ggml-rpc/ggml-rpc.cpp b/ggml/src/ggml-rpc/ggml-rpc.cpp
2-
index 29bc421d5..5eaa5479d 100644
2+
index df6ba5407..9610949b6 100644
33
--- a/ggml/src/ggml-rpc/ggml-rpc.cpp
44
+++ b/ggml/src/ggml-rpc/ggml-rpc.cpp
55
@@ -4,6 +4,8 @@

llama-box/patches/llama.cpp/model_py.patch

Lines changed: 3 additions & 3 deletions
Original file line numberDiff line numberDiff line change
@@ -1,8 +1,8 @@
11
diff --git a/convert_hf_to_gguf.py b/convert_hf_to_gguf.py
2-
index 82b005e84..02b01a7d2 100755
2+
index b8c7d97a7..b2145ce0d 100755
33
--- a/convert_hf_to_gguf.py
44
+++ b/convert_hf_to_gguf.py
5-
@@ -4706,6 +4706,123 @@ class XLMRobertaModel(BertModel):
5+
@@ -4811,6 +4811,123 @@ class XLMRobertaModel(BertModel):
66
return super().modify_tensors(data_torch, name, bid)
77

88

@@ -168,7 +168,7 @@ index 911eea504..3b731485e 100644
168168
MODEL_TENSOR.TOKEN_EMBD,
169169
MODEL_TENSOR.TOKEN_EMBD_NORM,
170170
diff --git a/gguf-py/gguf/tensor_mapping.py b/gguf-py/gguf/tensor_mapping.py
171-
index a0f11563a..159f8c8f0 100644
171+
index dc7c03b46..6f2d740ec 100644
172172
--- a/gguf-py/gguf/tensor_mapping.py
173173
+++ b/gguf-py/gguf/tensor_mapping.py
174174
@@ -167,6 +167,7 @@ class TensorNameMap:

llama-box/patches/llama.cpp/mrope.patch

Lines changed: 2 additions & 2 deletions
Original file line numberDiff line numberDiff line change
@@ -52,10 +52,10 @@ index cb8eff4a7..845c3994a 100644
5252
GGML_ASSERT( dst->type == GGML_TYPE_F16 || dst->type == GGML_TYPE_F32);
5353

5454
diff --git a/ggml/src/ggml-opencl/ggml-opencl.cpp b/ggml/src/ggml-opencl/ggml-opencl.cpp
55-
index bb8b310b9..f777e7d40 100644
55+
index 8ba1e00df..d6267161c 100644
5656
--- a/ggml/src/ggml-opencl/ggml-opencl.cpp
5757
+++ b/ggml/src/ggml-opencl/ggml-opencl.cpp
58-
@@ -6684,10 +6684,6 @@ static void ggml_cl_rope(ggml_backend_t backend, const ggml_tensor * src0, const
58+
@@ -6783,10 +6783,6 @@ static void ggml_cl_rope(ggml_backend_t backend, const ggml_tensor * src0, const
5959
const bool is_mrope = mode & GGML_ROPE_TYPE_MROPE;
6060
const bool is_vision = mode == GGML_ROPE_TYPE_VISION;
6161

llama-box/patches/llama.cpp/tool_calling.patch

Lines changed: 7 additions & 7 deletions
Original file line numberDiff line numberDiff line change
@@ -1,5 +1,5 @@
11
diff --git a/common/chat.cpp b/common/chat.cpp
2-
index 60805ab3b..ecdd0bbb7 100644
2+
index 316bd2417..bb97ac3a6 100644
33
--- a/common/chat.cpp
44
+++ b/common/chat.cpp
55
@@ -502,6 +502,13 @@ void common_chat_templates_free(struct common_chat_templates * tmpls) {
@@ -16,7 +16,7 @@ index 60805ab3b..ecdd0bbb7 100644
1616
bool common_chat_templates_was_explicit(const struct common_chat_templates * tmpls) {
1717
return tmpls->has_explicit_template;
1818
}
19-
@@ -1857,6 +1864,83 @@ static common_chat_params common_chat_templates_apply_jinja(
19+
@@ -1982,6 +1989,83 @@ static common_chat_params common_chat_templates_apply_jinja(
2020
return common_chat_params_init_generic(tmpl, params);
2121
}
2222

@@ -100,7 +100,7 @@ index 60805ab3b..ecdd0bbb7 100644
100100
// Legacy template route (adhoc C++ implementation of known templates), forward to llama_chat_apply_template.
101101
static common_chat_params common_chat_templates_apply_legacy(
102102
const struct common_chat_templates * tmpls,
103-
@@ -1915,6 +1999,17 @@ static common_chat_params common_chat_templates_apply_legacy(
103+
@@ -2041,6 +2125,17 @@ static common_chat_params common_chat_templates_apply_legacy(
104104
return params;
105105
}
106106

@@ -118,7 +118,7 @@ index 60805ab3b..ecdd0bbb7 100644
118118
common_chat_params common_chat_templates_apply(
119119
const struct common_chat_templates * tmpls,
120120
const struct common_chat_templates_inputs & inputs)
121-
@@ -1980,7 +2075,7 @@ common_chat_msg common_chat_parse(const std::string & input, bool is_partial, co
121+
@@ -2109,7 +2204,7 @@ common_chat_msg common_chat_parse(const std::string & input, bool is_partial, co
122122
try {
123123
common_chat_parse(builder);
124124
} catch (const common_chat_msg_partial_exception & ex) {
@@ -127,7 +127,7 @@ index 60805ab3b..ecdd0bbb7 100644
127127
if (!is_partial) {
128128
builder.clear_tools();
129129
builder.move_to(0);
130-
@@ -1988,8 +2083,8 @@ common_chat_msg common_chat_parse(const std::string & input, bool is_partial, co
130+
@@ -2117,8 +2212,8 @@ common_chat_msg common_chat_parse(const std::string & input, bool is_partial, co
131131
}
132132
}
133133
auto msg = builder.result();
@@ -140,10 +140,10 @@ index 60805ab3b..ecdd0bbb7 100644
140140
return msg;
141141
}
142142
diff --git a/common/chat.h b/common/chat.h
143-
index b014f9f0a..f709ef596 100644
143+
index eb628d8bc..a80089c1b 100644
144144
--- a/common/chat.h
145145
+++ b/common/chat.h
146-
@@ -167,10 +167,15 @@ common_chat_templates_ptr common_chat_templates_init(
146+
@@ -168,10 +168,15 @@ common_chat_templates_ptr common_chat_templates_init(
147147
const std::string & bos_token_override = "",
148148
const std::string & eos_token_override = "");
149149

llama.cpp

Submodule llama.cpp updated 60 files

0 commit comments

Comments
 (0)